# Quizzes

This section contains quick quizzes that help you verify your grasp of the core ideas before moving on. 
Quizzes are short, focused, and map directly to the topics in the User Guide.

To effectively use the self-assessment quizzes read through the corresponding User Guide, open the quiz linked in the User Guide,
and for each question try to figure out the correct answer. You will know immediately if you are correct or not.

You may also find links to the quizzes below.

- [](using-transformations-quiz)
- [](creating-custom-bodies-quiz)
- [](loading-worlds-quiz)
- [](visualizing-worlds-quiz)
- [](world-structure-manipulation-quiz)
- [](semantic-annotations-quiz)
- [](world-state-manipulation-quiz)
- [](regions-quiz)
- [](semantic-annotation-factories-quiz)
- [](persistence-of-annotated-worlds-quiz)
- [](graph-of-convex-sets-quiz)